@@ -3,8 +3,8 @@ begin
 rescue TypeError
   require 'backports/tools'
 
-  def open_with_options_hash(file, mode = nil, perm = Backports::Undefined, options = Backports::Undefined)
-    mode, perm = Backports.combine_mode_perm_and_option(mode, perm, options)
+  def open_with_options_hash(file, mode = nil, perm_or_options = Backports::Undefined)
+    mode, perm = Backports.combine_mode_perm_and_option(mode, perm_or_options)
     perm ||= 0666 # Avoid error on Rubinius, see issue #52
     if block_given?
       open_without_options_hash(file, mode, perm){|f| yield f}
@@ -13,7 +13,9 @@ rescue TypeError
     end
   end
 
-  Backports.alias_method_chain File, :open, :options_hash
+  class << File
+    Backports.alias_method_chain self, :open, :options_hash
+  end
 end
 
 if RUBY_VERSION < '1.9'
